@@ -1335,11 +1335,14 @@ class ModelStorage(Model):
             ifields = islice(ifields, 0, threshold)
             ffields.update(ifields)
 
+        require_context_field = False
         # add datetime_field
         for field in list(ffields.values()):
             if hasattr(field, 'datetime_field') and field.datetime_field:
-                datetime_field = self._fields[field.datetime_field]
-                ffields[field.datetime_field] = datetime_field
+                require_context_field = True
+                if field.datetime_field not in ffields:
+                    datetime_field = self._fields[field.datetime_field]
+                    ffields[field.datetime_field] = datetime_field
 
         # add depends of field with context
         for field in list(ffields.values()):
@@ -1348,13 +1351,15 @@ class ModelStorage(Model):
                 for context_field_name in eval_fields:
                     if context_field_name not in field.depends:
                         continue
-                    context_field = self._fields.get(context_field_name)
-                    if context_field not in ffields:
+                    require_context_field = True
+                    if context_field_name not in ffields:
+                        context_field = self._fields.get(context_field_name)
                         ffields[context_field_name] = context_field
 
         def filter_(id_):
-            return (name not in self._cache.get(id_, {})
-                and name not in self._local_cache.get(id_, {}))
+            return (id_ == self.id  # Ensure the value is read
+                or (name not in self._cache.get(id_, {})
+                    and name not in self._local_cache.get(id_, {})))
 
         def unique(ids):
             s = set()
@@ -1422,7 +1427,8 @@ class ModelStorage(Model):
                 self._transaction.set_user(self._user), \
                 self._transaction.reset_context(), \
                 self._transaction.set_context(self._context):
-            if self.id in self._cache and name in self._cache[self.id]:
+            if (self.id in self._cache and name in self._cache[self.id]
+                    and not require_context_field):
                 # Use values from cache
                 ids = islice(chain(islice(self._ids, index, None),
                         islice(self._ids, 0, max(index - 1, 0))),
@@ -1435,6 +1441,7 @@ class ModelStorage(Model):
                 read_data = self.read(list(ids), list(ffields.keys()))
             # create browse records for 'remote' models
             for data in read_data:
+                to_delete = set()
                 for fname, field in ffields.items():
                     fvalue = data[fname]
                     if field._type in ('many2one', 'one2one', 'one2many',
@@ -1453,10 +1460,11 @@ class ModelStorage(Model):
                             or field.context
                             or getattr(field, 'datetime_field', None)
                             or isinstance(field, fields.Function)):
-                        del data[fname]
+                        to_delete.add(fname)
                 if data['id'] not in self._cache:
                     self._cache[data['id']] = {}
-                self._cache[data['id']].update(data)
+                self._cache[data['id']].update(
+                    **{k: v for k, v in data.items() if k not in to_delete})
         return value
 
     @property
